@@ -78,8 +78,8 @@ void YClientContainer::handleButton(const XButtonEvent &button) {
                 mx = button.x_root;
                 my = button.y_root;
             }
-            if (doMove && getFrame()->canMove() ||
-                !doMove && getFrame()->canSize())
+            if ((doMove && getFrame()->canMove()) ||
+                (!doMove && getFrame()->canSize()))
             {
                 getFrame()->startMoveSize(doMove, 1,
                                           gx, gy,
@@ -155,6 +155,20 @@ void YClientContainer::releaseButtons() {
     grabActions();
 }
 
+void YClientContainer::regrabMouse() {
+    XUngrabButton(xapp->display(), AnyButton, AnyModifier, handle());
+
+    if (fHaveActionGrab)  {
+        fHaveActionGrab = false;
+        grabActions();
+    }
+
+    if (fHaveGrab ) {
+        fHaveGrab = false;
+        grabButtons();
+    }
+}
+
 void YClientContainer::grabActions() {
     if (clientMouseActions) {
         if (!fHaveActionGrab) {
