@@ -117,6 +117,8 @@ YWindowManager::~YWindowManager() {
 }
 
 void YWindowManager::grabKeys() {
+    XUngrabKey(xapp->display(), AnyKey, AnyModifier, handle());
+
 #ifdef CONFIG_ADDRESSBAR
     ///if (taskBar && taskBar->addressBar())
         GRAB_WMKEY(gKeySysAddressBar);
@@ -217,6 +219,13 @@ void YWindowManager::grabKeys() {
             grabButton(5, xapp->WinMask);
         }
     }
+    {
+        YFrameWindow *ff = topLayer();
+        while (ff != 0) {
+            ff->grabKeys();
+            ff = ff->nextLayer();
+        }
+    }
 }
 
 YProxyWindow::YProxyWindow(YWindow *parent): YWindow(parent) {
@@ -490,7 +499,7 @@ bool YWindowManager::handleWMKey(const XKeyEvent &key, KeySym k, unsigned int /*
 
 bool YWindowManager::handleKey(const XKeyEvent &key) {
     if (key.type == KeyPress) {
-        KeySym k = XKeycodeToKeysym(xapp->display(), key.keycode, 0);
+        KeySym k = XKeycodeToKeysym(xapp->display(), (KeyCode)key.keycode, 0);
         unsigned int m = KEY_MODMASK(key.state);
         unsigned int vm = VMod(m);
 
@@ -508,7 +517,7 @@ bool YWindowManager::handleKey(const XKeyEvent &key) {
         }
         return handled;
     } else if (key.type == KeyRelease) {
-        KeySym k = XKeycodeToKeysym(xapp->display(), key.keycode, 0);
+        KeySym k = XKeycodeToKeysym(xapp->display(), (KeyCode)key.keycode, 0);
         unsigned int m = KEY_MODMASK(key.state);
 
         (void)m;
@@ -630,11 +639,12 @@ void YWindowManager::handleMapRequest(const XMapRequestEvent &mapRequest) {
 
 void YWindowManager::handleUnmap(const XUnmapEvent &unmap) {
 #if 1
-    if (unmap.send_event)
-        if (unmap.window != handle())
+    if (unmap.send_event) {
+        if (unmap.window != handle() && handle() != 0)
             xapp->handleWindowEvent(unmap.window, *(XEvent *)&unmap);
         else
-            MSG(("unhandled root window unmap"));
+            MSG(("unhandled root window unmap: %lX %lX", (long)unmap.window, (long)handle()));
+    }
 #endif
 }
 
@@ -677,7 +687,9 @@ void YWindowManager::handleClientMessage(const XClientMessageEvent &message) {
             wmapp->actionPerformed(actionWindowList, 0);
             break;
         case ICEWM_ACTION_ABOUT:
+#ifndef LITE
             wmapp->actionPerformed(actionAbout, 0);
+#endif
             break;
         }
     }
@@ -1320,9 +1332,9 @@ void YWindowManager::placeWindow(YFrameWindow *frame,
             client->gravityOffsets(gx, gy);
 
             if (gx > 0)
-                posX -= 2 * frame->borderXN() - 1 - client->getBorder();
+                posX -= 2 * frame->borderXN() - client->getBorder() - 1;
             if (gy > 0)
-                posY -= 2 * frame->borderYN() + frame->titleYN() - 1 - client->getBorder();
+                posY -= 2 * frame->borderYN() + frame->titleYN() - client->getBorder() - 1;
         }
     }
 
@@ -1388,6 +1400,13 @@ YFrameWindow *YWindowManager::manageClient(Window win, bool mapClient) {
 #endif
         }
 
+        // temp workaround for flashblock problems
+        if (client->isEmbed()) {
+            warn("app trying to map XEmbed window 0x%X, ignoring", client->handle());
+            delete client;
+            goto end;
+        }
+
         client->setBorder(attributes.border_width);
         client->setColormap(attributes.colormap);
     }
@@ -1610,7 +1629,7 @@ bool YWindowManager::focusTop(YFrameWindow *f) {
     return true;
 }
 
-YFrameWindow *YWindowManager::getLastFocus(long workspace) {
+YFrameWindow *YWindowManager::getLastFocus(bool skipSticky, long workspace) {
     if (workspace == -1)
         workspace = activeWorkspace();
 
@@ -1626,7 +1645,10 @@ YFrameWindow *YWindowManager::getLastFocus(long workspace) {
     }
 
     if (toFocus == 0) {
-        for (int pass = 0; pass < 2; pass++) {
+        int pass = 0;
+        if (!skipSticky)
+            pass = 1;
+        for (; pass < 3; pass++) {
             for (YFrameWindow *w = lastFocusFrame();
                  w;
                  w = w->prevFocus())
@@ -1641,7 +1663,7 @@ YFrameWindow *YWindowManager::getLastFocus(long workspace) {
                     continue;
                 if (!w->visibleOn(workspace))
                     continue;
-                if (w->avoidFocus() || pass == 1)
+                if (w->avoidFocus() || pass == 2)
                     continue;
                 if (w->isSticky() || pass == 1)
                     continue;
@@ -1683,7 +1705,7 @@ void YWindowManager::focusLastWindow() {
     }
 
 /// TODO #warning "per workspace?"
-    YFrameWindow *toFocus = getLastFocus();
+    YFrameWindow *toFocus = getLastFocus(false);
 
     if (toFocus == 0) {
         focusTopWindow();
@@ -1947,7 +1969,7 @@ void YWindowManager::updateWorkArea() {
         }
 
         if (w->doNotCover() ||
-            limitByDockLayer && w->getActiveLayer() == WinLayerDock)
+            (limitByDockLayer && w->getActiveLayer() == WinLayerDock))
         {
             int midX = width() / 4;
             int midY = height() / 4;
@@ -2051,7 +2073,7 @@ void YWindowManager::resizeWindows() {
     for (YFrameWindow * f = topLayer(); f; f = f->nextLayer()) {
         if (f->inWorkArea()) {
             if (f->isMaximized())
-                f->updateDerivedSize(0);
+                f->updateDerivedSize(WinStateMaximizedVert | WinStateMaximizedHoriz);
                 f->updateLayout();
         }
     }
@@ -2059,7 +2081,7 @@ void YWindowManager::resizeWindows() {
 
 void YWindowManager::activateWorkspace(long workspace) {
     if (workspace != fActiveWorkspace) {
-        YFrameWindow *toFocus = getLastFocus(workspace);
+        YFrameWindow *toFocus = getLastFocus(true, workspace);
 
         lockFocus();
 ///        XSetInputFocus(app->display(), desktop->handle(), RevertToNone, CurrentTime);
