@@ -48,7 +48,7 @@ public:
     YWindowManager(YWindow *parent, Window win = 0);
     virtual ~YWindowManager();
 
-    void grabKeys();
+    virtual void grabKeys();
 
     virtual void handleButton(const XButtonEvent &button);
     virtual void handleClick(const XButtonEvent &up, int count);
@@ -122,7 +122,7 @@ public:
 
     void restackWindows(YFrameWindow *win);
     void focusTopWindow();
-    YFrameWindow *getLastFocus(long workspace = -1);
+    YFrameWindow *getLastFocus(bool skipSticky = false, long workspace = -1);
     void focusLastWindow();
     bool focusTop(YFrameWindow *f);
     void relocateWindows(long workspace, int dx, int dy);
