@@ -706,7 +706,7 @@ StartMenu::StartMenu(const char *name, YWindow *parent): MenuFileMenu(name, pare
 bool StartMenu::handleKey(const XKeyEvent &key) {
     // If meta key, close the popup
     if (key.type == KeyPress) {
-        KeySym k = XKeycodeToKeysym(xapp->display(), key.keycode, 0);
+        KeySym k = XKeycodeToKeysym(xapp->display(), (KeyCode)key.keycode, 0);
         int m = KEY_MODMASK(key.state);
 
         if (((k == xapp->Win_L) || (k == xapp->Win_R)) && m == 0) {
